@@ -142,7 +142,6 @@ class Insight_Definition:
         #logging.info("URL {}".format(query_url))
         r = s.post(url=query_url, json=body, headers=headers)
         r.raise_for_status()
-        print(r.json())
         self.components = r.json()["components"]
         return self.components[position]["id"]
 
@@ -164,7 +163,6 @@ class Insight_Definition:
         #logging.info("URL {}".format(query_url))
         r = s.post(url=query_url, json=body, headers=headers)
         r.raise_for_status()
-        print(r.json())
         self.components = r.json()["components"]
 
         if(query != "" and columns!=[]):
@@ -253,7 +251,6 @@ class Insight_Definition:
         #logging.info("URL {}".format(query_url))
         r = s.post(url=query_url, json=body, headers=headers)
         r.raise_for_status()
-        print(r.json())
         self.components = r.json()["components"]
 
         if (type != "" and query != "" and params!=[]):
@@ -846,7 +843,6 @@ class Insight_Definition:
         #logging.info("URL {}".format(query_url))
         r = s.post(url=query_url, json=body, headers=headers)
         r.raise_for_status()
-        print(r.json())
         self.components = r.json()["components"]
         return self.components[position]["id"]
 
@@ -875,7 +871,6 @@ class Insight_Definition:
 
         url += "/card/"
         url += self.slug
-        print(url)
         return url
 
     def add_admin(self, admin_email):
