@@ -61,22 +61,22 @@ class TimePeriodOperator(Enum):
     INTERVAL = auto()
 
 
-class CTDOperator(Enum):
-    CURR = auto()
-    PREV = auto()
-    PREV_CURR = auto()
-    START_PREV = auto()
-    NEXT = auto()
-    NEXT_END = auto()
-    CURR_NEXT = auto()
-    BFR = auto()
-    AFT = auto()
+class TimeOperator(Enum):
+    PERIOD = auto()
+    PREV_PERIOD = auto()
+    FROM_PREV_PERIOD = auto()
+    TO_PREV_PERIOD = auto()
+    NEXT_PERIOD = auto()
+    FROM_NEXT_PERIOD = auto()
+    TO_NEXT_PERIOD = auto()
+    FROM_PERIOD = auto()
+    TO_PERIOD = auto()
 
 
 @dataclass
 class Condition:
     field: Field
-    operator: Union[SQLOperator, CTDOperator, TimePeriodOperator, str]
+    operator: Union[SQLOperator, TimeOperator, TimePeriodOperator, str]
     value: Optional[List[Union[float, str]]] = None
     type: Optional[str] = None
     window: Optional[str] = None
